package FormValidator::LazyWay::Rule::Email::JA;

use strict;
use warnings;
use utf8;

sub email {
    'メールアドレスの書式',
}

sub email_loose {
    'メールアドレスの書式',
}

1;

=head1 NAME

FormValidator::LazyWay::Rule::Email::JA - Messages of Email Rule

=head1 METHOD

=head2 email

=head2 email_loose

=cut

