package FormValidator::LazyWay::Rule::DateTime::EN;

use strict;
use warnings;
use utf8;

sub datetime {'datetime'}
sub date  {'date'}
sub time {'time'}

1;

=head1 NAME

FormValidator::LazyWay::Rule::DateTime::EN - Messages of DateTime Rule

=cut
